@@ -50,7 +50,8 @@ def install(
 
     logger.info("Installing scvi-tools.")
 
-    if unfixed:
+    if not unfixed:
+        _run_command("pip install torchtext==0.12.0 --no-deps")
         _run_command("pip install pynndescent")
         # caching issues in colab causing pynndescent import to fail
         success = False
@@ -74,7 +75,7 @@ def install(
         command = f"pip install --quiet git+{repo}"
     _run_command(command)
 
-    if unfixed:
+    if not unfixed:
         _run_command("pip install --upgrade rich==10.0.0")
 
     logger.info("Install successful. Testing import.")
